@@ -28,28 +28,9 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
-        #TODO: collective.media function hasMedia() hardcoded here again and customized to return the first result. This fucking sucks!!
-        #event.hasMedia()
-        results = []
-        
-        catalog = getToolByName(self.context, 'portal_catalog')
-        plone_utils = getToolByName(self.context, 'plone_utils')
-        path = item.getPath() + "/"
-        
-        if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic"):
-            results = catalog.searchResults(path = {'query' : path}, type = ['Image', 'Link'], sort_on = 'getObjPositionInParent')
-        elif item.portal_type == "Topic":
-            if item.limitNumber:
-                results = catalog.searchResults(item.buildQuery())[:item.itemCount]
-            else:
-                results = catalog.searchResults(item.buildQuery())
-        
-        for res in results:
-            if res.portal_type == "Image":
-                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(res.getURL(), scale), 'title':item.Title}
-            #TODO: Somehow res has no remoteUrl. Could it be a brain vs. object thing?
-            #elif res.portal_type == "Link" and (res.remoteUrl.find("youtube.com") > -1 or res.remoteUrl.find("vimeo.com") > -1):
-            #    resultArray.append(res)
+        lead = item.leadMedia
+        if lead is not None:
+            return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
     
     
     def getTwoWayRelatedContent(self):
@@ -124,7 +105,8 @@ class EventArchiveListingView(CommonBrowserView):
         return Batch(final_res, pagesize, start=b_start)
     
     def innerResults(self, item, limit=3):
-        all_results = item.getObject().queryCatalog(batch=False)
+        #TODO: If we can query specifically for the hasMedia then we don't need to bypass the batching anymore
+        all_results = item.getObject().queryCatalog()
         final_res = []
         for res in all_results:
             if self.eventIsDocumented(res):
@@ -141,26 +123,25 @@ class EventArchiveListingView(CommonBrowserView):
         end = DateTime(year,12,31) 
         date_range_query = {'query': (start, end), 'range': 'min:max'}
 
-        results = catalog.queryCatalog({"portal_type": "Media Event",
+        if not only_documented:
+            results = catalog.queryCatalog({"portal_type": "Media Event",
                                  "start": date_range_query,
                                  "sort_on": "start",
                                  "sort_order": "reverse",
                                  "review_state": "published"})
-        
-        if not only_documented:
-            return results
         else:
-            filtered = []
-            for event in results:
-                if self._eventIsDocumented(event):
-                    filtered.append(event)
-            return filtered
+            results = catalog.queryCatalog({"portal_type": "Media Event",
+                                 "start": date_range_query,
+                                 "sort_on": "start",
+                                 "sort_order": "reverse",
+                                 "review_state": "published",
+                                 "hasMedia": True})
+        return results
     
     def yearIsDocumented(self, year):
         """
         Checks if a year has any documented events
         """
-        #TODO: This check will make the website slow... this should be encapsulated and optimized. should be done on collective.media instead.
         try:
             int(year)
         except:
@@ -188,32 +169,7 @@ class EventArchiveListingView(CommonBrowserView):
         if self._showall():
             return True
         else:
-            #TODO: collective.media function hasMedia() hardcoded here again. This fucking sucks!!
-            #event.hasMedia()
-            item = event
-            results = []
-            
-            catalog = getToolByName(self.context, 'portal_catalog')
-            plone_utils = getToolByName(self.context, 'plone_utils')
-            path = item.getPath() + "/"
-            
-            if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic"):
-                results = catalog.searchResults(path = {'query' : path}, type = ['Image', 'Link'], sort_on = 'getObjPositionInParent')
-            elif item.portal_type == "Topic":
-                if item.limitNumber:
-                    results = catalog.searchResults(item.buildQuery())[:item.itemCount]
-                else:
-                    results = catalog.searchResults(item.buildQuery())
-            
-            resultArray = []
-            
-            for res in results:
-                if res.portal_type == "Image":
-                    resultArray.append(res)
-                #elif res.portal_type == "Link" and (res.remoteUrl.find("youtube.com") > -1 or res.remoteUrl.find("vimeo.com") > -1):
-                #    resultArray.append(res)
-            
-            return len(resultArray) > 0
+            return event.hasMedia
         
     def _showall(self):
         return self.request.get('showallyears', False)
